from django.apps import AppConfig


class DjangoSassConfig(AppConfig):
    name = "django_sass"
